/**
 * Stores a property parameter without any type check
 * @param path [in] property path
 * @param value [in] property value
 */
function storeSubParameter(path, value) {
    try 
    {
        lInfo.logln('store at |' + path + "| value: |" + value + "|" );
        Property.setProperty(path, value);
        Property.setFlag(path, 'ARCHIVE', true);
    }
    catch (e)
    {
        lWarn.logln("Exception beim storeSubParameter " + e + " Path " + path  + " value " + value);
    }        
}

/**
 * Store a integer property parameter.
 * converts provided value whenever possible to an integer. Discard the the value if this is not possible.
 * @param path [in] property path
 * @param value [in] value to store should be integer
 * @returns {Boolean} returns false if value could not be converted to integer
 */
function checkAndStoreIntParameter(path, value) {
    try 
    {
        lInfo.logln('store integer at |' + path + "| value: |" + value + "|" );
        var sucessCode = false;
        var intValue = parseInt("" + value);
        if (!isNaN(intValue)) {
            Property.setProperty(path, intValue);
            Property.setFlag(path, 'ARCHIVE', true);
            sucessCode = true;
        } else {
            lWarn.logln("Typ-Fehler beim Speichern der Property entries/" + path);
        }
        return sucessCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreIntParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

/**
 * Store a string property parameter.
 * check weather the provided value is a string. In case it's a number it is converted to string, 
 * in any other cases it is discarded
 * @param path [in] property path
 * @param value [in] value to store should be string or at least a number
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreStringParameter(path, value) {
    try 
    {
        lInfo.logln('store string at |' + path + "| value: |" + value + "|" );
        var sucessCode = false;
        var stringValue = (typeof(value) === "number") ? String(value) : value;
        if (typeof(stringValue) === "string") {
            Property.setProperty(path, stringValue);
            Property.setFlag(path, 'ARCHIVE', true);
            sucessCode = true;
        } else {
            lWarn.logln("Typ-Fehler beim Speichern der Property entries/" + path);
        }
        return sucessCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreStringParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

/**
 * Store a dsuid as string property parameter.
 * check weather the provided value is a string. In case it's a number it is converted to string, 
 * if it is undefined it tries to convert dsid to dsuid, in any other cases it is discarded
 * @param path [in] property path
 * @param dsuid [in] value to store should be string
 * @param dsid [in] dsid value to be converted in dsuid if not available
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreDSUIDParameter(path, dsuid, dsid) {
    try 
    {
        lInfo.logln('store dsuid at |' + path + "| value: |" + dsuid + "|" );
        var successCode = false;
        var stringValue;
        if (typeof(dsuid) === 'string') {
            Property.setProperty(path, dsuid);
            Property.setFlag(path, 'ARCHIVE', true);
            successCode = true;
        } else {
            if (typeof(dsid) === 'string') {
                stringValue = dSID2dSUID(dsid);
                if (typeof(stringValue) === "string") {
                    Property.setProperty(path, stringValue);
                    Property.setFlag(path, 'ARCHIVE', true);
                    successCode = true;
                }                
                lInfo.logln("store converted dsid");
            } else {
                lWarn.logln('Typ-Fehler beim Speichern der Property entries/' + path)
            }
        }
        return successCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreDSUIDParameter " + e + " Path " + path  + " value " + dsuid);
        return false;
    }        
}

/**
 * Store a boolean property parameter.
 * convert value if possible. In case In case conversion is not possible 
 * the value is discarded.
 * @param path [in] property path
 * @param value [in] value to store should be a boolean
 * @returns {Boolean} returns false if value could not be converted
 */
function checkAndStoreBoolParameter(path, value) {
    try 
    {
        lInfo.logln('store boolean at |' + path + "| value: |" + value + "|" );
        var successCode = false;
        var boolValue = false;
        if (typeof(value) === "boolean") {
            Property.setProperty(path, value);
            Property.setFlag(path, 'ARCHIVE', true);       
            successCode = true;
        } else {
            if (typeof(value) === "string") {
                if (value === "true") {
                    boolValue = true;
                }
                Property.setProperty(path, boolValue);
                Property.setFlag(path, 'ARCHIVE', true);       
                successCode = true;
            } else {
                lWarn.logln("Typ-Fehler beim Speichern der Property entries/" + path);
            }
        }
        return successCode;
    }
    catch (e)
    {
        lWarn.logln("Exception beim checkAndStoreBoolParameter " + e + " Path " + path  + " value " + value);
        return false;
    }        
}

function dSID2dSUID(dSID) {
    try {
        //copy the first 6 bytes (12 characters to the new dsuid
        var dSUID = dSID.slice(0, 12);
        //insert 4 bytes of 0
        dSUID += '00000000';
        //append the remaining 6 bytes (12 chars) of the dsid
        dSUID += dSID.slice(12, 24);
        //finaly add 1 byte of 0
        dSUID += '00';
        return dSUID;
    } catch (e) {
        lWarn.logln('Exception in store-property-helper::dSID2dSUID ' + e);
        return '';
    }
}